@@ -18,14 +18,14 @@
 #                                                                         # 
 ###########################################################################
 
-hergm.mcmc <- function(original.formula, max_number, initialize, network, model, hyper_prior, parametric, MHproposal, MCMCparams, verbose, alpha_shape, alpha_rate, alpha, eta_mean_mean, eta_mean_sd, eta_precision_shape, eta_precision_rate, eta_mean, eta_sd, mean_between, eta, indicator, parallel, simulate, seeds, mh_scale, variational, temperature, predictions, perturb) 
+hergm.mcmc <- function(original.formula, max_number, initialize, network, model, hyper_prior, parametric, MHproposal, MCMCparams, verbose, scaling, alpha_shape, alpha_rate, alpha, eta_mean_mean, eta_mean_sd, eta_precision_shape, eta_precision_rate, eta_mean, eta_sd, mean_between, eta, all_indicators_fixed, indicators_fixed, indicator, parallel, simulate, seeds, mh_scale, variational, temperature, predictions, perturb) 
 {
   # Prepare
-  if (simulate == FALSE) scalefactor <- hergm.set.mcmc(max_number, initialize, network, model, hyper_prior, parametric, MHproposal, MCMCparams, verbose, indicator, alpha_shape, alpha_rate, alpha,  eta_mean_mean, eta_mean_sd, eta_precision_shape, eta_precision_rate, eta_mean, eta_sd, mean_between, eta, simulate, parallel, seeds, predictions, variational, temperature, mh_scale, perturb) # The last argument is the initial value of the scale factor
+  if (simulate == FALSE) scalefactor <- hergm.set.mcmc(max_number, initialize, network, model, hyper_prior, parametric, MHproposal, MCMCparams, verbose, all_indicators_fixed, indicators_fixed, indicator, scaling, alpha_shape, alpha_rate, alpha,  eta_mean_mean, eta_mean_sd, eta_precision_shape, eta_precision_rate, eta_mean, eta_sd, mean_between, eta, simulate, parallel, seeds, predictions, variational, temperature, mh_scale, perturb) # The last argument is the initial value of the scale factor
   Clist <- ergm.Cprepare(network, model)
   if (Clist$dir == FALSE) maxedges <- Clist$n * (Clist$n - 1) / 2 # Undirected
   else maxedges <- Clist$n * (Clist$n - 1) # Directed
-  hergm_list <- hergm.preprocess(max_number, initialize=FALSE, network, model, hyper_prior, parametric, Clist, MHproposal, MCMCparams, maxedges, alpha_shape, alpha_rate, alpha,  eta_mean_mean, eta_mean_sd, eta_precision_shape, eta_precision_rate, eta_mean, eta_sd, mean_between, eta, indicator, simulate, parallel, variational, temperature, predictions, verbose, perturb)
+  hergm_list <- hergm.preprocess(max_number, initialize, network, model, hyper_prior, parametric, Clist, MHproposal, MCMCparams, maxedges, scaling, alpha_shape, alpha_rate, alpha,  eta_mean_mean, eta_mean_sd, eta_precision_shape, eta_precision_rate, eta_mean, eta_sd, mean_between, eta, all_indicators_fixed, indicators_fixed, indicator, simulate, parallel, variational, temperature, predictions, verbose, perturb)
   if (simulate == FALSE) hergm_list$scalefactor <- scalefactor # Set scale factor
   else if (hergm_list$hyper_prior == 1)
     {
@@ -75,19 +75,19 @@ hergm.mcmc <- function(original.formula, max_number, initialize, network, model,
 
   # Store
   output <- list() 
-  output$network <- network
   output$n <- Clist$n
+  output$network <- network
   output$model <- model
   output$max_number <- hergm_list$max_number
   output$number_fixed <- hergm_list$number_fixed
   output$d1 <- hergm_list$d1
   output$d2 <- hergm_list$d2
+  output$hyper_prior <- hergm_list$hyper_prior
   output$parallel <- hergm_list$parallel
   output$simulate <- hergm_list$simulate
   output$sample_size <- min(10000, hergm_list$MCMCparams$samplesize)
   if (simulate == TRUE) 
     {
-    output$sample <- sample$sample
     number_edges <- sample$sample_heads[1]
     if (number_edges == 0)
       {
@@ -104,7 +104,6 @@ hergm.mcmc <- function(original.formula, max_number, initialize, network, model,
     }
   output$predictions <- predictions
   output$sample <- sample$mcmc 
-
   output
 }
 
