@@ -21,7 +21,7 @@
 hergm.permutation.wrapper <- function(number) 
 {
   number_permutations <- factorial(number)
-  permutations <- matrix(0, nrow = number_permutations, ncol = number)
+  permutations <- vector(length=number_permutations*number)
   for (i in 1:number) permutations[i] = i
   output <- .C("Permutations",
                      as.integer(number),
