@@ -27,6 +27,7 @@ hergm.wrapper <- function(seed, hergm_list)
     sample <- .C("Simulation",
     as.integer(hergm_list$dependence),
     as.integer(hergm_list$hierarchical),
+    as.double(hergm_list$scaling),
     as.integer(hergm_list$d),
     as.integer(hergm_list$d1),
     as.integer(hergm_list$d2),
@@ -96,7 +97,7 @@ hergm.wrapper <- function(seed, hergm_list)
     as.integer(hergm_list$model_type),
     as.integer(hergm_list$dependence),
     as.integer(hergm_list$hierarchical),
-    as.integer(hergm_list$decomposable),
+    as.double(hergm_list$scaling),
     as.integer(hergm_list$d),
     as.integer(hergm_list$d1),
     as.integer(hergm_list$d2),
